
## CATO-CLI - mutation.site.updateSecondaryAzureVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateSecondaryAzureVSocket) for documentation on this operation.

### Usage for mutation.site.updateSecondaryAzureVSocket:

`catocli mutation site updateSecondaryAzureVSocket -h`

`catocli mutation site updateSecondaryAzureVSocket <json>`

`catocli mutation site updateSecondaryAzureVSocket "$(cat < updateSecondaryAzureVSocket.json)"`

`catocli mutation site updateSecondaryAzureVSocket '{"updateSecondaryAzureVSocketInput": {"floatingIp": {"floatingIp": "IPAddress"}, "id": {"id": "ID"}, "interfaceIp": {"interfaceIp": "IPAddress"}}}'`

#### Operation Arguments for mutation.site.updateSecondaryAzureVSocket ####
`accountId` [ID] - (required) N/A 
`updateSecondaryAzureVSocketInput` [UpdateSecondaryAzureVSocketInput] - (required) N/A 
